@@ -13,7 +13,7 @@ except ImportError:
 from django.http import HttpResponse
 from django.conf import settings
 
-from settings import IGNORE_PATHS
+from settings import DISABLED_PATHS, ENABLED_PATHS
 
 def redirect_to_facebook_authorization(redirect_uri):
     """
@@ -91,16 +91,30 @@ def get_facebook_profile(oauth_token):
     
     return json.loads(connection.getresponse().read())
     
-def is_ignored_path(path):
+def is_disabled_path(path):
     """
     Determine whether or not the path matches one or more paths
-    in the IGNORE_PATHS setting.
+    in the DISABLED_PATHS setting.
     
     Arguments:
     path -- A string describing the path to be matched.
     """
-    for ignore_path in IGNORE_PATHS:
-        match = re.search(ignore_path, path[1:])
+    for disabled_path in DISABLED_PATHS:
+        match = re.search(disabled_path, path[1:])
+        if match:
+            return True
+    return False
+    
+def is_enabled_path(path):
+    """
+    Determine whether or not the path matches one or more paths
+    in the ENABLED_PATHS setting.
+    
+    Arguments:
+    path -- A string describing the path to be matched.
+    """
+    for enabled_path in ENABLED_PATHS:
+        match = re.search(enabled_path, path[1:])
         if match:
             return True
     return False
\ No newline at end of file
